openssl: Implementation of the SSL and TLS protocols
====================================================

Description
-----------

From wikipedia: OpenSSL is an open source implementation of the SSL and
TLS protocols. The core library (written in the C programming language)
implements the basic cryptographic functions and provides various
utility functions. Wrappers allowing the use of the OpenSSL library in a
variety of computer languages are available.

License
-------

- Apache License v2 (considered compatible with GPL v3)


Upstream Contact
----------------

-  http://openssl.org/
